@@ -7,7 +7,7 @@ use MooX::ReturnModifiers;
 use Carp qw/croak/;
 use Scalar::Util;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub import {
     my $target    = caller;
@@ -47,7 +47,7 @@ MooX::ValidateSubs - Validating sub routine parameters via Type::Tiny.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -81,7 +81,7 @@ Version 0.04
         
     }
 
-    package Extends::I::Announced::My::Rerturn
+    package Extends::I::Announced::My::Return
 
     use Moo;
     extends 'Welcome::To::A::World::Of::Types';
@@ -91,7 +91,7 @@ Version 0.04
     );
 
     around goodbye_world = sub {
-        $_[1] = 'And then dissapeared again';
+        $_[1] = 'And then disappeared again';
     };
 
 =head1 EXPORT
